==> blanco.plugin.logmessage_0.0.1-src.zip: src/blanco/logmessage/valueobject/BlancoLogMessageStructure.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.logmessage.valueobject;

import java.util.List;

/**
 * BlancoLogMessagêȂŗpValueObjectłB
 */
public class BlancoLogMessageStructure {
    /**
     * tB[h [name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * bZ[W`IDw肵܂BK{ڂłB
     */
    private String fName;

    /**
     * tB[h [package]
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     */
    private String fPackage;

    /**
     * tB[h [description]
     *
     * ڂ̌^ [java.lang.String]<br>
     * bZ[W`̐Lڂ܂B
     */
    private String fDescription;

    /**
     * tB[h [suffix]
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     */
    private String fSuffix;

    /**
     * tB[h [idEmbedding]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * bZ[WIDߍ݂sǂB
     */
    private boolean fIdEmbedding = false;

    /**
     * tB[h [fieldList]
     *
     * ڂ̌^ [java.util.List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>]<br>
     * Kl   [new java.util.ArrayList<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>()]<br>
     * tB[hێ郊XgB
     */
    private List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure> fFieldList = new java.util.ArrayList<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>();

    /**
     * tB[h [name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * bZ[W`IDw肵܂BK{ڂłB
     *
     * @param argName tB[h[name]Ɋi[l
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h[name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * bZ[W`IDw肵܂BK{ڂłB
     *
     * @return tB[h[name]Ɋi[Ăl
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [package]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     *
     * @param argPackage tB[h[package]Ɋi[l
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h[package]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     *
     * @return tB[h[package]Ɋi[Ăl
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [description]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * bZ[W`̐Lڂ܂B
     *
     * @param argDescription tB[h[description]Ɋi[l
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h[description]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * bZ[W`̐Lڂ܂B
     *
     * @return tB[h[description]Ɋi[Ăl
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [suffix]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     *
     * @param argSuffix tB[h[suffix]Ɋi[l
     */
    public void setSuffix(final String argSuffix) {
        fSuffix = argSuffix;
    }

    /**
     * tB[h[suffix]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     *
     * @return tB[h[suffix]Ɋi[Ăl
     */
    public String getSuffix() {
        return fSuffix;
    }

    /**
     * tB[h [idEmbedding]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * bZ[WIDߍ݂sǂB
     *
     * @param argIdEmbedding tB[h[idEmbedding]Ɋi[l
     */
    public void setIdEmbedding(final boolean argIdEmbedding) {
        fIdEmbedding = argIdEmbedding;
    }

    /**
     * tB[h[idEmbedding]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * bZ[WIDߍ݂sǂB
     *
     * @return tB[h[idEmbedding]Ɋi[Ăl
     */
    public boolean getIdEmbedding() {
        return fIdEmbedding;
    }

    /**
     * tB[h [fieldList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>]<br>
     * tB[hێ郊XgB
     *
     * @param argFieldList tB[h[fieldList]Ɋi[l
     */
    public void setFieldList(final List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure> argFieldList) {
        fFieldList = argFieldList;
    }

    /**
     * tB[h[fieldList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>]<br>
     * Kl   [new java.util.ArrayList<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>()]<br>
     * tB[hێ郊XgB
     *
     * @return tB[h[fieldList]Ɋi[Ăl
     */
    public List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure> getFieldList() {
        return fFieldList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.logmessage.valueobject.BlancoLogMessageStructure[");
        buf.append("name=" + fName);
        buf.append(",package=" + fPackage);
        buf.append(",description=" + fDescription);
        buf.append(",suffix=" + fSuffix);
        buf.append(",idEmbedding=" + fIdEmbedding);
        buf.append(",fieldList=" + fFieldList);
        buf.append("]");
        return buf.toString();
    }
}

==> blanco.plugin.logmessage_0.0.3-src.zip: src/blanco/logmessage/valueobject/BlancoLogMessageStructure.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.logmessage.valueobject;

import java.util.List;

/**
 * BlancoLogMessagêȂŗpValueObjectłB
 */
public class BlancoLogMessageStructure {
    /**
     * tB[h [name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ObZ[W`IDw肵܂BK{ڂłB
     */
    private String fName;

    /**
     * tB[h [package]
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     */
    private String fPackage;

    /**
     * tB[h [description]
     *
     * ڂ̌^ [java.lang.String]<br>
     * bZ[W`̐Lڂ܂B
     */
    private String fDescription;

    /**
     * tB[h [suffix]
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     */
    private String fSuffix;

    /**
     * tB[h [idEmbedding]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * bZ[WIDߍ݂sǂB
     */
    private boolean fIdEmbedding = false;

    /**
     * tB[h [stdout]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * Wo͂𐶐邩ǂB
     */
    private boolean fStdout = false;

    /**
     * tB[h [fieldList]
     *
     * ڂ̌^ [java.util.List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>]<br>
     * Kl   [new java.util.ArrayList<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>()]<br>
     * tB[hێ郊XgB
     */
    private List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure> fFieldList = new java.util.ArrayList<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>();

    /**
     * tB[h [name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ObZ[W`IDw肵܂BK{ڂłB
     *
     * @param argName tB[h[name]Ɋi[l
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h[name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ObZ[W`IDw肵܂BK{ڂłB
     *
     * @return tB[h[name]Ɋi[Ăl
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [package]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     *
     * @param argPackage tB[h[package]Ɋi[l
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h[package]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     *
     * @return tB[h[package]Ɋi[Ăl
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [description]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * bZ[W`̐Lڂ܂B
     *
     * @param argDescription tB[h[description]Ɋi[l
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h[description]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * bZ[W`̐Lڂ܂B
     *
     * @return tB[h[description]Ɋi[Ăl
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [suffix]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     *
     * @param argSuffix tB[h[suffix]Ɋi[l
     */
    public void setSuffix(final String argSuffix) {
        fSuffix = argSuffix;
    }

    /**
     * tB[h[suffix]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     *
     * @return tB[h[suffix]Ɋi[Ăl
     */
    public String getSuffix() {
        return fSuffix;
    }

    /**
     * tB[h [idEmbedding]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * bZ[WIDߍ݂sǂB
     *
     * @param argIdEmbedding tB[h[idEmbedding]Ɋi[l
     */
    public void setIdEmbedding(final boolean argIdEmbedding) {
        fIdEmbedding = argIdEmbedding;
    }

    /**
     * tB[h[idEmbedding]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * bZ[WIDߍ݂sǂB
     *
     * @return tB[h[idEmbedding]Ɋi[Ăl
     */
    public boolean getIdEmbedding() {
        return fIdEmbedding;
    }

    /**
     * tB[h [stdout]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Wo͂𐶐邩ǂB
     *
     * @param argStdout tB[h[stdout]Ɋi[l
     */
    public void setStdout(final boolean argStdout) {
        fStdout = argStdout;
    }

    /**
     * tB[h[stdout]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * Wo͂𐶐邩ǂB
     *
     * @return tB[h[stdout]Ɋi[Ăl
     */
    public boolean getStdout() {
        return fStdout;
    }

    /**
     * tB[h [fieldList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>]<br>
     * tB[hێ郊XgB
     *
     * @param argFieldList tB[h[fieldList]Ɋi[l
     */
    public void setFieldList(final List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure> argFieldList) {
        fFieldList = argFieldList;
    }

    /**
     * tB[h[fieldList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>]<br>
     * Kl   [new java.util.ArrayList<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure>()]<br>
     * tB[hێ郊XgB
     *
     * @return tB[h[fieldList]Ɋi[Ăl
     */
    public List<blanco.logmessage.valueobject.BlancoLogMessageFieldStructure> getFieldList() {
        return fFieldList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.logmessage.valueobject.BlancoLogMessageStructure[");
        buf.append("name=" + fName);
        buf.append(",package=" + fPackage);
        buf.append(",description=" + fDescription);
        buf.append(",suffix=" + fSuffix);
        buf.append(",idEmbedding=" + fIdEmbedding);
        buf.append(",stdout=" + fStdout);
        buf.append(",fieldList=" + fFieldList);
        buf.append("]");
        return buf.toString();
    }
}
